package com.sooka.common.utils;


import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.Map;

/**
 * Http 访问
 */
public abstract class HttpRequest {


    public interface IProgress {
        void downloadProgress(int percent, long localSize, long totalSize);
    }

    public void getAsync(final Map<String, Object> params, final String toUrl) {
        new Thread(new Runnable() {
            @Override
            public void run() {
                get(params, toUrl);
            }
        }).start();
    }

    public void get(Map<String, Object> params, String toUrl) {
        sendRequest(toUrl, Http.stringFromParams(params), false);
    }

    public void postAsync(final Map<String, Object> params, final String toUrl) {
        new Thread(new Runnable() {
            @Override
            public void run() {
                post(params, toUrl);
            }
        }).start();
    }

    public void post(Map<String, Object> params, String toUrl) {
        sendRequest(toUrl, Http.stringFromParams(params), true);
    }

    private void sendRequest(String url, String params, boolean post) {
        if (url.equals("")||url == null) return;
//        Log.i("---------", ""+TextUtils.isEmpty(url));


        Response response = new Response(0);
        HttpURLConnection connection = null;
        InputStreamReader in = null;
        try {
            if (!post) {
                url = url + "?" + params;
            }
            URL uriAPI = new URL(url);
            connection = (HttpURLConnection) uriAPI.openConnection();
            // 设置连接主机超时时间
//            connection.setConnectTimeout(10 * 1000);
            //设置从主机读取数据超时
//            connection.setReadTimeout(10 * 1000);
            // 设置是否使用缓存  默认是true
            connection.setUseCaches(true);

            if (post) {

                connection.setDoInput(true);
                connection.setDoOutput(true);
                connection.setRequestMethod("POST");
                connection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
                connection.setRequestProperty("Charset", "UTF-8");

                connection.setRequestProperty("Content-Length", "" + params.length());
                System.out.println(url + "?" + params);

                // 写入post参数
                DataOutputStream dop = new DataOutputStream(connection.getOutputStream());
                dop.writeBytes(params);
                dop.flush();
                dop.close();
            }

            long timestamp = System.currentTimeMillis();
            response.state = connection.getResponseCode();
            response.timestamp = connection.getHeaderFieldDate("Date", 0);
            if (response.timestamp != 0) {
                response.timestamp += System.currentTimeMillis() - timestamp;
            }

            if (response.state == 200) {
                in = new InputStreamReader(connection.getInputStream());

                BufferedReader bufferedReader = new BufferedReader(in);
                StringBuilder strBuilder = new StringBuilder();
                String line;
                while ((line = bufferedReader.readLine()) != null && !_cancel) {
                    strBuilder.append(line);
                }
                response.content = strBuilder.toString();
            }

        } catch (Exception e) {
            response.content = e.getLocalizedMessage();
            error(e);
        } finally {
            if (connection != null) {
                connection.disconnect();
            }
            if (in != null) {
                try {
                    in.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            response.cancel = _cancel;
            _cancel = false;
            complete(response);
        }
    }

    private boolean _cancel = false;
    public void cancel() {
        _cancel = true;
    }

    public abstract void complete(Response response);

    public void error(Exception e)
    {
        e.printStackTrace();
    }

    /**
     * A dummy item representing a piece of content.
     */
    public static class Response {
        public boolean cancel = false;
        public int state;
        public String content;
        public long timestamp = 0;

        public Response(int state) {
            this.state = state;
            this.content = "";
        }

        @Override
        public String toString() {
            return content;
        }
    }
}
