package com.sooka.module.api;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import com.sooka.common.utils.ControllerUtil;
import com.sooka.component.lucene.util.IndexObject;
import com.sooka.module.web.cms.service.PjService;
import com.sooka.module.web.cms.service.ZzxdService;
import com.sooka.module.web.system.service.TSysApiAccessKeyService;
import com.sooka.mybatis.model.TCmsPj;
import com.sooka.mybatis.model.TSysApiAccessKey;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.http.HttpResponse;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.message.BasicHeader;
import org.apache.http.protocol.HTTP;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import sun.misc.BASE64Decoder;

import javax.servlet.http.HttpServletRequest;
import java.io.*;
import java.text.SimpleDateFormat;
import java.util.*;

@Slf4j
@RestController
@RequestMapping("/pubilc_interface")
public class PublicInterface {

    @Autowired
    TSysApiAccessKeyService tSysApiAccessKeyService;

    @Autowired
    private PjService pjService;

    @Autowired
    private ZzxdService zzxdService;

    @Value("${system.http.url12345}")
    private String url12345;

    @Value("${system.http.channelAddOrder1}")
    private String channelAddOrder1;//8.1新增渠道工单

    @Value("${system.http.MyQueryOrder1}")
    private String MyQueryOrder1;//8.3我的诉求查询接口

    @Value("${system.http.singleQueryOrder1}")
    private String singleQueryOrder1;// 8.4单个工单查询接口

    @Value("${system.http.submitAppraise1}")
    private String submitAppraise1;// 8.5提交评价接口

    @Value("${system.http.queryPublicOrde1}")
    private String queryPublicOrde1;// 8.6查询案例公开

    @Value("${system.http.getOrderCount}")
    private String getOrderCount;// 8.13查询下单量和公开量


    private static long LIMIT = 5000;

    SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");//设置日期格式

    /**
     * 8.1新增渠道工单  接口
     */
    @RequestMapping("/channelAddOrder")
    @ResponseBody
    public JSONObject channelAddOrde(@RequestBody String requestBody, HttpServletRequest request){
        JSONObject jsonObject = JSONObject.parseObject(requestBody);
        JSONObject resultJson = new JSONObject();
        log.info(df.format(new Date()) + "--通通办APP《新增渠道工单channelAddOrder》参数:" + jsonObject.toString());

        String access_key = jsonObject.getString("access_key");//调用者的access_key
        long timestamp = Long.parseLong(jsonObject.getString("timestamp"));// 调用接口的时间戳
        String sign = jsonObject.getString("sign");//调用者的sign

        //1:验证ip
        String ip = request.getRemoteAddr();//访问接口ip
        Map<String, Object> map = new HashMap<>();
        TSysApiAccessKey key = this.tSysApiAccessKeyService.selectByAccessKey(access_key);
        if(key == null || !key.getIP().equals(ip)){
            map.put("code","10030");
            map.put("msg","政务服务提示：IP不合法");
            log.info(df.format(new Date()) + "--通通办APP《新增渠道工单channelAddOrder》返回:code:10030-msg:IP不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //2:验证 加密签名
        if(sign == null || sign == "" || !sign.equals(mySign(access_key , timestamp))){
            map.put("code","10000");
            map.put("msg","政务服务提示：加密签名不合法");
            log.info(df.format(new Date()) + "--通通办APP《新增渠道工单channelAddOrder》返回:code:10000-msg:加密签名不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }
//        //3:验证时效性
//        long now = System.currentTimeMillis();
//        log.info("通通办APP《新增渠道工单channelAddOrder》时间戳为:" + now);
//        if(now - timestamp > LIMIT || now < timestamp){
//            map.put("code","10070");
//            map.put("msg","政务服务提示：调用间隔时长低于设置的时间范围或时间戳不合法");
//            log.info(df.format(new Date()) + "--通通办APP《新增渠道工单channelAddOrder》返回:code:10070-msg:调用间隔时长低于设置的时间范围或时间戳不合法");
//            JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(map));
//            return paramsjson;
//        }

        String url = url12345 + channelAddOrder1;
        Map<String, Object> params = new HashMap<>();
        params.put("orderType", jsonObject.getString("orderType"));// 工单类型
        params.put("requestTopic", jsonObject.getString("requestTopic"));// 诉求标题,必填
        params.put("requestContent", jsonObject.getString("requestContent"));// 诉求内容,必填
        params.put("contactName", jsonObject.getString("contactName"));// 联系人姓名,必填
        params.put("contactTel", jsonObject.getString("contactTel"));// 联系人电话,必填
        params.put("certType", jsonObject.getString("certType"));// 证件类型(1身份证)
        params.put("certCode", jsonObject.getString("certCode"));// 证件号码
        params.put("contactAddress", jsonObject.getString("contactAddress"));// 联系地址
        params.put("requestArea", jsonObject.getString("requestArea"));// 事发地址
        params.put("requestFrom", jsonObject.getString("requestFrom"));// 来源渠道(app)
        params.put("pubIntent", jsonObject.getString("pubIntent"));// 公开意向(y—公开 n—不公开),必填
        Map<String, String> m = new HashMap<String, String>();
        params.put("fileName", jsonObject.getString("fileName"));//
        params.put("fileBytes", jsonObject.getString("fileBytes"));//
        params.put("fileUrl", jsonObject.getString("fileUrl"));//
        params.put("type", jsonObject.getString("type"));//
//        List<Map<String, String>> info = new ArrayList<Map<String, String>>();
//        info.add(m);
//        params.put("fileDatas", info);
        JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(params));
//        zzxdService.save(pojo);// 保存至本地数据库
        String result = post(paramsjson, url);// 注册
        log.info(df.format(new Date()) + "--通通办APP《新增渠道工单channelAddOrder》返回result:" + result);
        return JSON.parseObject(result);
    }

    /**
     * 8.3我的诉求查询  接口
     */
    @RequestMapping("/listMyAppeal")
    @ResponseBody
    public JSONObject listMyAppeal(@RequestBody String requestBody, HttpServletRequest request){
        JSONObject jsonObject = JSONObject.parseObject(requestBody);
        JSONObject resultJson = new JSONObject();
        log.info(df.format(new Date()) + "--通通办APP《我的诉求查询listMyAppeal》参数:" + jsonObject.toString());

        String access_key = jsonObject.getString("access_key");//调用者的access_key
        long timestamp = Long.parseLong(jsonObject.getString("timestamp"));// 调用接口的时间戳
        String sign = jsonObject.getString("sign");//调用者的sign

        //1:验证ip
        String ip = request.getRemoteAddr();//访问接口ip
        Map<String, Object> map = new HashMap<>();
        TSysApiAccessKey key = this.tSysApiAccessKeyService.selectByAccessKey(access_key);
        if(key == null || !key.getIP().equals(ip)){
            map.put("code","10030");
            map.put("msg","政务服务提示：IP不合法");
            log.info(df.format(new Date()) + "--通通办APP《我的诉求查询listMyAppeal》返回:code:10030-msg:IP不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //2:验证 加密签名
        if(sign == null || sign == "" || !sign.equals(mySign(access_key , timestamp))){
            map.put("code","10000");
            map.put("msg","政务服务提示：加密签名不合法");
            log.info(df.format(new Date()) + "--通通办APP《我的诉求查询listMyAppeal》返回:code:10000-msg:加密签名不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //3:验证时效性
//        long now = System.currentTimeMillis();
//        log.info("通通办APP《我的诉求查询listMyAppeal》时间戳为:" + now);
//        if(now - timestamp > LIMIT || now < timestamp){
//            map.put("code","10070");
//            map.put("msg","政务服务提示：调用间隔时长低于设置的时间范围或时间戳不合法");
//            log.info(df.format(new Date()) + "--通通办APP《我的诉求查询listMyAppeal》返回:code:10070-msg:调用间隔时长低于设置的时间范围或时间戳不合法");
//            JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(map));
//            return paramsjson;
//        }

        String url = url12345 + MyQueryOrder1;
        Map<String, Object> params = new HashMap<>();
        params.put("proWoCode", jsonObject.getString("proWoCode"));// 工单编号
        params.put("telNum", jsonObject.getString("telNum"));// 电话号码,必填
        params.put("state", jsonObject.getString("state"));// 工单状态
        params.put("orderType", jsonObject.getString("orderType"));// 工单类型
        params.put("startNum", jsonObject.getString("startNum"));// 开始条数
        params.put("endNum", jsonObject.getString("endNum"));// 结束条数

        JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(params));
        String result = post(paramsjson, url);// 注册
        log.info(df.format(new Date()) + "--通通办APP《我的诉求查询listMyAppeal》返回result:" + result);
        return JSON.parseObject(result);
    }

    /**
     * 8.4 单个工单查询 接口
     */
    @RequestMapping("/singleQueryOrder")
    @ResponseBody
    public JSONObject singleQueryOrder(@RequestBody String requestBody, HttpServletRequest request){
        JSONObject jsonObject = JSONObject.parseObject(requestBody);
        JSONObject resultJson = new JSONObject();
        log.info(df.format(new Date()) + "--通通办APP《单个工单查询singleQueryOrder》参数:" + jsonObject.toString());

        String access_key = jsonObject.getString("access_key");//调用者的access_key
        long timestamp = Long.parseLong(jsonObject.getString("timestamp"));// 调用接口的时间戳
        String sign = jsonObject.getString("sign");//调用者的sign

        //1:验证ip
        String ip = request.getRemoteAddr();//访问接口ip
        Map<String, Object> map = new HashMap<>();
        TSysApiAccessKey key = this.tSysApiAccessKeyService.selectByAccessKey(access_key);
        if(key == null || !key.getIP().equals(ip)){
            map.put("code","10030");
            map.put("msg","政务服务提示：IP不合法");
            log.info(df.format(new Date()) + "--通通办APP《单个工单查询singleQueryOrder》返回:code:10030-msg:IP不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //2:验证 加密签名
        if(sign == null || sign == "" || !sign.equals(mySign(access_key , timestamp))){
            map.put("code","10000");
            map.put("msg","政务服务提示：加密签名不合法");
            log.info(df.format(new Date()) + "--通通办APP《单个工单查询singleQueryOrder》返回:code:10000-msg:加密签名不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //3:验证时效性
//        long now = System.currentTimeMillis();
//        log.info("通通办APP《单个工单查询singleQueryOrder》时间戳为:" + now);
//        if(now - timestamp > LIMIT || now < timestamp){
//            map.put("code","10070");
//            map.put("msg","政务服务提示：调用间隔时长低于设置的时间范围或时间戳不合法");
//            log.info(df.format(new Date()) + "--通通办APP《单个工单查询singleQueryOrder》返回:code:10070-msg:调用间隔时长低于设置的时间范围或时间戳不合法");
//            JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(map));
//            return paramsjson;
//        }

        String url = url12345 + singleQueryOrder1;
        Map<String, Object> params = new HashMap<>();
        params.put("proWoCode", jsonObject.getString("proWoCode"));// 工单编号,必填
        params.put("telNum", jsonObject.getString("telNum"));// 电话号码

        JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(params));
        String result = post(paramsjson, url);// 注册
        log.info(df.format(new Date()) + "--通通办APP《单个工单查询singleQueryOrder》返回result:" + result);
        return JSON.parseObject(result);
    }

    /**
     * 8.5提交评价  接口
     */
    @RequestMapping("/submitAppraise")
    @ResponseBody
    public JSONObject submitAppraise(@RequestBody String requestBody, HttpServletRequest request){
        JSONObject jsonObject = JSONObject.parseObject(requestBody);
        JSONObject resultJson = new JSONObject();
        log.info(df.format(new Date()) + "--通通办APP《提交评价submitAppraise》参数:" + jsonObject.toString());

        String access_key = jsonObject.getString("access_key");//调用者的access_key
        long timestamp = Long.parseLong(jsonObject.getString("timestamp"));// 调用接口的时间戳
        String sign = jsonObject.getString("sign");//调用者的sign

        //1:验证ip
        String ip = request.getRemoteAddr();//访问接口ip
        Map<String, Object> map = new HashMap<>();
        TSysApiAccessKey key = this.tSysApiAccessKeyService.selectByAccessKey(access_key);
        if(key == null || !key.getIP().equals(ip)){
            map.put("code","10030");
            map.put("msg","政务服务提示：IP不合法");
            log.info(df.format(new Date()) + "--通通办APP《提交评价submitAppraise》返回:code:10030-msg:IP不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //2:验证 加密签名
        if(sign == null || sign == "" || !sign.equals(mySign(access_key , timestamp))){
            map.put("code","10000");
            map.put("msg","政务服务提示：加密签名不合法");
            log.info(df.format(new Date()) + "--通通办APP《提交评价submitAppraise》返回:code:10000-msg:加密签名不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //3:验证时效性
//        long now = System.currentTimeMillis();
//        log.info("通通办APP《提交评价submitAppraise》时间戳为:" + now);
//        if(now - timestamp > LIMIT || now < timestamp){
//            map.put("code","10070");
//            map.put("msg","政务服务提示：调用间隔时长低于设置的时间范围或时间戳不合法");
//            log.info(df.format(new Date()) + "--通通办APP《提交评价submitAppraise》返回:code:10070-msg:调用间隔时长低于设置的时间范围或时间戳不合法");
//            JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(map));
//            return paramsjson;
//        }

        String url = url12345 + submitAppraise1;
        Map<String, Object> params = new HashMap<>();
        params.put("proWoCode", jsonObject.getString("proWoCode"));// 工单编号,必填
        params.put("appraisesatisfy", jsonObject.getString("appraisesatisfy"));// 评价满意度,必填
        params.put("appraiseTime", jsonObject.getString("appraiseTime"));// 评价时间,必填
        JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(params));
        String result = post(paramsjson, url);// 注册
        log.info(df.format(new Date()) + "--通通办APP《提交评价submitAppraise》返回result:" + result);
        return JSON.parseObject(result);
    }

    /**
     * 8.6查询案例公开 接口
     */
    @RequestMapping("/queryPublicOrder")
    @ResponseBody
    public JSONObject queryPublicOrder(@RequestBody String requestBody, HttpServletRequest request){
        JSONObject jsonObject = JSONObject.parseObject(requestBody);
        JSONObject resultJson = new JSONObject();
        log.info(df.format(new Date()) + "--通通办APP《查询案例公开queryPublicOrder》参数:" + jsonObject.toString());

        String access_key = jsonObject.getString("access_key");//调用者的access_key
        long timestamp = Long.parseLong(jsonObject.getString("timestamp"));// 调用接口的时间戳
        String sign = jsonObject.getString("sign");//调用者的sign

        //1:验证ip
        String ip = request.getRemoteAddr();//访问接口ip
        Map<String, Object> map = new HashMap<>();
        TSysApiAccessKey key = this.tSysApiAccessKeyService.selectByAccessKey(access_key);
        if(key == null || !key.getIP().equals(ip)){
            map.put("code","10030");
            map.put("msg","政务服务提示：IP不合法");
            log.info(df.format(new Date()) + "--通通办APP《查询案例公开queryPublicOrder》返回:code:10030-msg:IP不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //2:验证 加密签名
        if(sign == null || sign == "" || !sign.equals(mySign(access_key , timestamp))){
            map.put("code","10000");
            map.put("msg","政务服务提示：加密签名不合法");
            log.info(df.format(new Date()) + "--通通办APP《查询案例公开queryPublicOrder》返回:code:10000-msg:加密签名不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //3:验证时效性
//        long now = System.currentTimeMillis();
//        log.info("通通办APP《查询案例公开queryPublicOrder》时间戳为:" + now);
//        if(now - timestamp > LIMIT || now < timestamp){
//            map.put("code","10070");
//            map.put("msg","政务服务提示：调用间隔时长低于设置的时间范围或时间戳不合法");
//            log.info(df.format(new Date()) + "--通通办APP《查询案例公开queryPublicOrder》返回:code:10070-msg:调用间隔时长低于设置的时间范围或时间戳不合法");
//            JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(map));
//            return paramsjson;
//        }

        String url = url12345 + queryPublicOrde1;
        Map<String, Object> params = new HashMap<>();
        params.put("proWoCode", jsonObject.getString("proWoCode"));// 工单编号
        params.put("orderType", jsonObject.getString("orderType"));// 工单类型
        params.put("startNum", jsonObject.getString("startNum"));// 开始条数,必填
        params.put("endNum", jsonObject.getString("endNum"));// 结束条数,必填
        JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(params));
        String result = post(paramsjson, url);// 注册
        log.info(df.format(new Date()) + "--通通办APP《查询案例公开queryPublicOrder》返回result:" + result);
        System.out.println(result);
        return JSON.parseObject(result);
    }

    /**
     * 8.13查询下单量和公开量 接口
     */
    @RequestMapping("/getOrderCount")
    @ResponseBody
    public JSONObject getOrderCount(@RequestBody String requestBody, HttpServletRequest request){
        JSONObject jsonObject = JSONObject.parseObject(requestBody);
        JSONObject resultJson = new JSONObject();
        log.info(df.format(new Date()) + "--通通办APP《查询下单量和公开量getOrderCount》参数:" + jsonObject.toString());

        String access_key = jsonObject.getString("access_key");//调用者的access_key
        long timestamp = Long.parseLong(jsonObject.getString("timestamp"));// 调用接口的时间戳
        String sign = jsonObject.getString("sign");//调用者的sign

        //1:验证ip
        String ip = request.getRemoteAddr();//访问接口ip
        Map<String, Object> map = new HashMap<>();
        TSysApiAccessKey key = this.tSysApiAccessKeyService.selectByAccessKey(access_key);
        if(key == null || !key.getIP().equals(ip)){
            map.put("code","10030");
            map.put("msg","政务服务提示：IP不合法");
            log.info(df.format(new Date()) + "--通通办APP《查询下单量和公开量getOrderCount》返回:code:10030-msg:IP不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //2:验证 加密签名
        if(sign == null || sign == "" || !sign.equals(mySign(access_key , timestamp))){
            map.put("code","10000");
            map.put("msg","政务服务提示：加密签名不合法");
            log.info(df.format(new Date()) + "--通通办APP《查询下单量和公开量getOrderCount》返回:code:10000-msg:加密签名不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //3:验证时效性
//        long now = System.currentTimeMillis();
//        log.info("通通办APP《查询下单量和公开量getOrderCount》时间戳为:" + now);
//        if(now - timestamp > LIMIT || now < timestamp){
//            map.put("code","10070");
//            map.put("msg","政务服务提示：调用间隔时长低于设置的时间范围或时间戳不合法");
//            log.info(df.format(new Date()) + "--通通办APP《查询下单量和公开量getOrderCount》返回:code:10070-msg:调用间隔时长低于设置的时间范围或时间戳不合法");
//            JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(map));
//            return paramsjson;
//        }

        String url = url12345 + getOrderCount;
        Map<String, Object> params = new HashMap<>();
        params.put("callType", jsonObject.getString("callType"));// 诉求渠道
        JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(params));
        String result = post(paramsjson, url);// 注册
        log.info(df.format(new Date()) + "--通通办APP《查询下单量和公开量getOrderCount》返回result:" + result);
        return JSON.parseObject(result);
    }

    @PostMapping(value = "/uploadFile")
    @ResponseBody
    public JSONObject uploadFile(@RequestBody String requestBody, HttpServletRequest request) throws IOException {
        JSONObject jsonObject = JSONObject.parseObject(requestBody);
        JSONObject resultJson = new JSONObject();
        log.info(df.format(new Date()) + "--通通办APP《上传文件upload》参数:" + jsonObject.toString());

        String access_key = jsonObject.getString("access_key");//调用者的access_key
        long timestamp = Long.parseLong(jsonObject.getString("timestamp"));// 调用接口的时间戳
        String sign = jsonObject.getString("sign");//调用者的sign

        //1:验证ip
        String ip = request.getRemoteAddr();//访问接口ip
        Map<String, Object> map = new HashMap<>();
        TSysApiAccessKey key = this.tSysApiAccessKeyService.selectByAccessKey(access_key);
        if(key == null || !key.getIP().equals(ip)){
            map.put("code","10030");
            map.put("msg","政务服务提示：IP不合法");
            log.info(df.format(new Date()) + "--通通办APP《上传文件upload》返回:code:10030-msg:IP不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //2:验证 加密签名
        if(sign == null || sign == "" || !sign.equals(mySign(access_key , timestamp))){
            map.put("code","10000");
            map.put("msg","政务服务提示：加密签名不合法");
            log.info(df.format(new Date()) + "--通通办APP《上传文件upload》返回:code:10000-msg:加密签名不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        String suffix = jsonObject.getString("suffix");//上传文件后缀
        String base64File = jsonObject.getString("fileBytes");//调用者的access_key

        String filePath = "D:/tomcat-9/webapps/ROOT/WEB-INF/classes/static/uploadfile";
        String fileName = String.valueOf(System.currentTimeMillis()) + "." + suffix;
        String fileUrl = filePath + "/" + fileName;
        File file = null;
        if (base64File == null) { // 文件为空
            map.put("code","10101");
            map.put("msg","政务服务提示：文件字节码不能为空");
            log.info(df.format(new Date()) + "--通通办APP《上传文件upload》返回:code:10101-msg:文件字节码不能为空");
            JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return paramsjson;
        } else {
            BASE64Decoder decoder = new BASE64Decoder();
            String baseValue = base64File.replaceAll(" ", "+");//前台在用Ajax传base64值的时候会把base64中的+换成空格，所以需要替换回来。
            byte[] b = decoder.decodeBuffer(baseValue.replace("data:image/jpeg;base64,", ""));//去除base64中无用的部分
            base64File = base64File.replace("base64,", "");
            File file1 = new File(filePath);
            if (!file1.exists() && !file1.isDirectory()) {//判断文件路径下的文件夹是否存在，不存在则创建
                file1.mkdirs();
            }
            try {
                for (int i = 0; i < b.length; ++i) {
                    if (b[i] < 0) {// 调整异常数据
                        b[i] += 256;
                    }
                }
                file = new File(fileUrl);
                // 如果要返回file文件这边return就可以了,存到临时文件中
                OutputStream out = new FileOutputStream(file.getPath());
                out.write(b);
                out.flush();
                out.close();
                map.put("code","0");
                map.put("msg","处理成功");
                map.put("fileName",fileName);
                log.info(df.format(new Date()) + "--通通办APP《上传文件upload》返回:code:0-msg:处理成功");
                JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(map));
                return paramsjson;
            } catch (Exception e) {
                e.printStackTrace();
                map.put("code","00001");
                map.put("msg","上传文件失败,程序异常！");
                log.info(df.format(new Date()) + "--通通办APP《上传文件upload》返回:code:00001-msg:上传文件失败,程序异常！");
                JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(map));
                return paramsjson;
            }
        }
    }

//    @PostMapping(value = "/uploadFile")
//    @ResponseBody
//    public JSONObject uploadFile(@RequestParam("file") MultipartFile file ) {
////        JSONObject jsonObject = JSONObject.parseObject(requestBody);
////        JSONObject resultJson = new JSONObject();
//        JSONObject jsonObject = new JSONObject();
////        String access_key = jsonObject.getString("access_key");//调用者的access_key
////        long timestamp = Long.parseLong(jsonObject.getString("timestamp"));// 调用接口的时间戳
////        String sign = jsonObject.getString("sign");//调用者的sign
//        //1:验证ip
////        String ip = request.getRemoteAddr();//访问接口ip
////        Map<String, Object> map = new HashMap<>();
////        TSysApiAccessKey key = this.tSysApiAccessKeyService.selectByAccessKey(access_key);
////        if(key == null || !key.getIP().equals(ip)){
////            map.put("code","10030");
////            map.put("msg","政务服务提示：IP不合法");
////            log.info(df.format(new Date()) + "--通通办APP《上传文件uploadFile》返回:code:10030-msg:IP不合法");
////            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
////            return resultJson;
////        }
////        //2:验证 加密签名
////        if(sign == null || sign == "" || !sign.equals(mySign(access_key , timestamp))){
////            map.put("code","10000");
////            map.put("msg","政务服务提示：加密签名不合法");
////            log.info(df.format(new Date()) + "--通通办APP《上传文件uploadFile》返回:code:10000-msg:加密签名不合法");
////            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
////            return resultJson;
////        }
//
//        if (file.isEmpty()) {
//            jsonObject.put("code","10101");
//            jsonObject.put("msg","政务服务提示：文件不能为空");
//            log.info(df.format(new Date()) + "--通通办APP《上传文件uploadFile》返回:code:10101-msg:文件不能为空");
//            return jsonObject;
//        }
//        // 创建输入输出流
//        InputStream inputStream = null;
//        OutputStream os = null;
//        try {
//            byte[] bytes = file.getBytes();
//            String fileName = file.getOriginalFilename();
//            long times = System.currentTimeMillis();
//            String time = String.valueOf(times);
//            String str1 = fileName.substring(0, fileName.indexOf("."));
//            String str2 = fileName.substring(str1.length() + 1, fileName.length());
//            fileName = time + '.' + str2;// 文件名(时间戳)
//            long fileSize = file.getSize();
//            long size = 20 * 1024 * 1024;
//            long maxsize = 100 * 1024 * 1024;// (附件最大100M)
//            if (fileSize > maxsize) {
//                jsonObject.put("code","10101");
//                jsonObject.put("msg","上传附件不能超过100M！");
//                log.info(df.format(new Date()) + "--通通办APP《上传文件uploadFile》返回:code:10101-msg:上传附件不能超过100M！");
//                return jsonObject;
//            }
//            String filePath = "D:/tomcat-9/webapps/ROOT/WEB-INF/classes/static/uploadfile";
//            int len;
//            byte[] bs = new byte[1024];
//            // 输出的文件流保存到本地文件
//            File tempFile = new File(filePath);
//            if (!tempFile.exists()) {
//                tempFile.mkdirs();
//            }
//            os = new FileOutputStream(tempFile.getPath() + File.separator + fileName);
//            inputStream = file.getInputStream();
//            // 开始读取
//            while ((len = inputStream.read(bs)) != -1) {
//                os.write(bs, 0, len);
//            }
//            String fileUrl = filePath + "/" + fileName;
//
//            byte[] b = Files.readAllBytes(Paths.get(fileUrl));
//            String fileBytes = Base64.getEncoder().encodeToString(b);
//            // 大于20M 传fileUrl)
//            if (fileSize > size) {
//                jsonObject.put("fileUrl", fileUrl);
//            } else {
//                // 文件小于20M 传fileBytes
//                jsonObject.put("fileBytes", fileBytes);
//            }
//            jsonObject.put("fileName", fileName);
//            jsonObject.put("code","0");
//            jsonObject.put("msg","处理成功");
//        } catch (Exception e) {
//            e.printStackTrace();
//            jsonObject.put("code","00001");
//            jsonObject.put("msg","上传失败，程序异常！");
//        } finally {
//            // 无论成功与否，都有关闭输入输出流
//            if (inputStream != null) {
//                try {
//                    inputStream.close();
//                } catch (IOException e) {
//                    e.printStackTrace();
//                }
//            }
//            if (os != null) {
//                try {
//                    os.close();
//                } catch (IOException e) {
//                    e.printStackTrace();
//                }
//            }
//        }
//        return jsonObject;
//    }

    /**
     * 提交评价
     */
    @RequestMapping("/savePJ")
    @ResponseBody
    public JSONObject savePJ(@RequestBody String requestBody, HttpServletRequest request) {
        JSONObject jsonObject = JSONObject.parseObject(requestBody);
        JSONObject resultJson = new JSONObject();
        log.info(df.format(new Date()) + "--通通办APP《提交评价savePJ》参数:" + jsonObject.toString());

        String access_key = jsonObject.getString("access_key");//调用者的access_key
        long timestamp = Long.parseLong(jsonObject.getString("timestamp"));// 调用接口的时间戳
        String sign = jsonObject.getString("sign");//调用者的sign

        //1:验证ip
        String ip = request.getRemoteAddr();//访问接口ip
        Map<String, Object> map = new HashMap<>();
        TSysApiAccessKey key = this.tSysApiAccessKeyService.selectByAccessKey(access_key);
        if(key == null || !key.getIP().equals(ip)){
            map.put("code","10030");
            map.put("msg","政务服务提示：IP不合法");
            log.info(df.format(new Date()) + "--通通办APP《提交评价savePJ》返回:code:10030-msg:IP不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //2:验证 加密签名
        if(sign == null || sign == "" || !sign.equals(mySign(access_key , timestamp))){
            map.put("code","10000");
            map.put("msg","政务服务提示：加密签名不合法");
            log.info(df.format(new Date()) + "--通通办APP《提交评价savePJ》返回:code:10000-msg:加密签名不合法");
            resultJson = JSONObject.parseObject(JSONObject.toJSONString(map));
            return resultJson;
        }

        //3:验证时效性
//        long now = System.currentTimeMillis();
//        System.out.println("通通办APP访问【提交评价】接口时的时间戳为:" + now);
//        if(now - timestamp > LIMIT || now < timestamp){
//            map.put("code","10070");
//            map.put("msg","政务服务提示：调用间隔时长低于设置的时间范围或时间戳不合法");
//            log.info(df.format(new Date()) + "--通通办APP《提交评价savePJ》返回:code:10070-msg:调用间隔时长低于设置的时间范围或时间戳不合法");
//            JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(map));
//            return paramsjson;
//        }

        SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");// 设置日期格式
        String appraiseTime = df.format(new Date());
        int Score = Integer.parseInt(jsonObject.getString("score"));//分数
        int Score1 = Score / 5;
        String proWoCode = jsonObject.getString("proWoCode");

        TCmsPj pojo = this.pjService.findById(Integer.valueOf(proWoCode));
        if(pojo == null){
            map.put("code","0101");
            map.put("msg","系统无该工单：" + proWoCode);
            log.info(df.format(new Date()) + "--通通办APP《提交评价savePJ》返回:code:0101-msg:系统无该工单" + proWoCode);
            JSONObject result = JSONObject.parseObject(JSONObject.toJSONString(map));
            return result;
        }else{
            String submitAppraise2 = "";
            submitAppraise2 = url12345 + submitAppraise1;
            Map<String, Object> params = new HashMap<>();
            params.put("proWoCode", pojo.getDataId().toString());// 工单编号
            params.put("appraisesatisfy", Score1);// 评价满意度
            params.put("appraiseTime", appraiseTime);// 评价时间
            JSONObject paramsjson = JSONObject.parseObject(JSONObject.toJSONString(params));
            System.out.println(paramsjson);
            String result_12345 = post(paramsjson, submitAppraise2);// 注册

            pojo.setIp(ControllerUtil.getRemoteAddress(request));
            if (pojo.getId() != null) {
                pjService.update(pojo);
            }else {
                pjService.save(pojo);
            }
            map.put("code","0");
            map.put("msg","处理成功");
            log.info(df.format(new Date()) + "--通通办APP《提交评价savePJ》返回:code:0-msg:处理成功");
            JSONObject result = JSONObject.parseObject(JSONObject.toJSONString(map));
            return result;
        }

    }

    /**
     * 查询评价列表
     */
    @RequestMapping("/selectPj")
    public JSONObject selectPj(@RequestBody String requestBody, HttpServletRequest request) {
        Map<String, Object> map = null;
        try {
            JSONObject jsonObject = JSONObject.parseObject(requestBody);
            String proWoCode = jsonObject.getString("proWoCode");
            TCmsPj pojo = new TCmsPj();
            pojo.setDataId(proWoCode);
            PageInfo p = pjService.page(1, 20, pojo);

            List<IndexObject> list;
            map = new HashMap<>();
            if (p != null) {
                list = p.getList();
                map.put("model",JSON.toJSONString(list));
                map.put("code","0");
                map.put("msg","处理成功");
                log.info(df.format(new Date()) + "--通通办APP《查询评价列表selectPj》返回:code:0-msg:处理成功");
            } else {
                map.put("code","0");
                map.put("msg","处理成功，该工单暂无评价");
                log.info(df.format(new Date()) + "--通通办APP《查询评价列表selectPj》返回:code:0-msg:处理成功，该工单暂无评价");
            }
        } catch (Exception e) {
            e.printStackTrace();
            map.put("code","000000");
            map.put("msg","程序异常");
            log.info(df.format(new Date()) + "--通通办APP《查询评价列表selectPj》返回:code:000000-msg:程序异常");
        }
        JSONObject result = JSONObject.parseObject(JSONObject.toJSONString(map));
        return result;
    }

    public static String post(JSONObject json, String URL) {
        HttpClient client = new DefaultHttpClient();
        HttpPost post = new HttpPost(URL);
        post.setHeader("Content-Type", "application/json");
        post.addHeader("Authorization", "Basic YWRtaW46");
        String result = "";
        try {
            StringEntity s = new StringEntity(json.toString(), "utf-8");
            s.setContentEncoding(new BasicHeader(HTTP.CONTENT_TYPE, "application/json"));
            post.setEntity(s);
            // 发送请求
            HttpResponse httpResponse = client.execute(post);
            // 获取响应输入流
            InputStream inStream = httpResponse.getEntity().getContent();
            BufferedReader reader = new BufferedReader(new InputStreamReader(inStream, "utf-8"));
            StringBuilder strber = new StringBuilder();
            String line = null;
            while ((line = reader.readLine()) != null)
                strber.append(line + "\n");
            inStream.close();
            result = strber.toString();
            if (httpResponse.getStatusLine().getStatusCode() == org.apache.http.HttpStatus.SC_OK) {
                System.out.println("请求服务器成功");
            } else {
                System.out.println("请求服务端失败");
            }
        } catch (Exception e) {
            System.out.println("请求异常");
            throw new RuntimeException(e);
        }
        return result;
    }

    /**
     *  接口验证
     *      1.验证访问ip
     */
    public boolean verifyIP(String ip, String access_key){
        Map<String, Object> map = new HashMap<>();
        TSysApiAccessKey key = this.tSysApiAccessKeyService.selectByAccessKey(access_key);
        return key.getIP().equals(ip);
    }

    public static String mySign(String access_key, long timestamp){
        //字典序排序
        String[] arr = {access_key,String.valueOf(timestamp )};
        Arrays.sort(arr);
        //按排序后的前后顺序连成串
        StringBuffer buf = new StringBuffer();
        buf.append(arr[0]).append(arr[1]);
        String befStr = buf.toString();
        //SHA1加密
        String mySign = DigestUtils.shaHex(befStr.getBytes());
        return mySign;
    }
    /**
     *  接口验证
     *      1.验证访问时效性
     */
    public boolean verifyTime(String timestamp){
        long now = System.currentTimeMillis();
        long ll = now - Long.parseLong(timestamp);
        return ll > LIMIT;
    }

    /**
     * 8.2修改渠道工单  接口
     */
//    @RequestMapping("/channelEditOrder")
//    @ResponseBody
    public JSONObject channelEditOrder(@RequestBody String requestBody, HttpServletRequest request){
        return null;
    }

    public static void main(String args[]){
        String access_key = "xsKKKhW74u6uOxpAwAwacFlh8HSD";
        long timestamp = System.currentTimeMillis();
        String sign = mySign(access_key, timestamp);
        System.out.println(timestamp);
        System.out.println(sign);
    }

}
